#include <TH1.h>
#include <TCanvas.h>
#include <TImage.h>
#include <TFile.h>
#include <TVirtualPad.h>

#include "RootTools.h"

void NicePad(TVirtualPad * pad, Float_t mT, Float_t mR, Float_t mB, Float_t mL) {
	pad->SetTopMargin(mT);
	pad->SetBottomMargin(mB);
	pad->SetLeftMargin(mL);
	pad->SetRightMargin(mR);
}

Bool_t gImgExportPNG = kTRUE;
Bool_t gImgExportEPS = kTRUE;
Bool_t gImgExportPDF = kFALSE;

void ExportPNG(TCanvas * can, const TString & path) {
	TImage * img = TImage::Create();
	img->FromPad(can);
	TString filename = path + TString::Format("%s.png", can->GetName());
	img->WriteImage(filename);
	delete img;
}

void ExportEPS(TCanvas * can, const TString & path) {
//	Int_t oldLevel = gErrorIgnoreLevel;
//	gErrorIgnoreLevel = kWarning;
	TString filename = path + TString::Format("%s.eps", can->GetName());
	can->Print(filename);
//	gErrorIgnoreLevel = oldLevel;
}

void ExportPDF(TCanvas * can, const TString & path) {
//	Int_t oldLevel = gErrorIgnoreLevel;
//	gErrorIgnoreLevel = kWarning;
	TString filename = path + TString::Format("%s.pdf", can->GetName());
	can->Print(filename);
//	gErrorIgnoreLevel = oldLevel;
}

void ExportImages(TCanvas * can, const TString & path) {
//	if (!gHasImgExportEnabled)
//		return;

//	if (gImgExportPNG)
		ExportPNG(can, path);
//	if (gImgExportEPS)
		ExportEPS(can, path);
//	if (gImgExportPDF)
		ExportPDF(can, path);
}

void SaveAndClose(TCanvas* can, TFile* f, Bool_t export_images, const TString & path) {
	can->Update();

	if (f)
		can->Write();

	if (export_images)
		ExportImages(can, path);

	can->Close();
}


int main() {
	TH1I * hist = new TH1I("h", "h", 100, 0, 100);

	TCanvas * can = new TCanvas("can", "asd", 800, 600);
	TFile * file = TFile::Open("test.root", "RECREATE");

	can->cd();
	hist->Draw();

//	NicePad(gPad, 0.9, 0.9, 0.1, 0.1);
	RootTools::NicePad(gPad, 0.9, 0.9, 0.1, 0.1);

	SaveAndClose(can, file, kTRUE, "./");

	file->Close();

	return 0;
}
